@@ -27,7 +27,7 @@
 static bool createConnection()
 {
     QSqlDatabase db = QSqlDatabase::addDatabase("QSQLITE");
-    db.setDatabaseName("dlh.db");
+    db.setDatabaseName(QDir::homePath().append("/MyDocs/dlh.db"));
     if (!db.open()) {
         QMessageBox::critical(0, QObject::tr("Cannot open database"),
         QObject::tr("Unable to establish a database connection.\n\n"
@@ -37,7 +37,7 @@ static bool createConnection()
     QSqlQuery query;
     query.exec("create table dlh (start varchar(20) primary key, "
                "end varchar(20), wb number, wa number, dw number, "
-               "mlb number, mla number, dml number)");
+               "mlb number, mla number, dml number, note varchar(500))");
     return true;
 }
 
@@ -54,6 +54,7 @@ Widget::Widget(QWidget *parent)
     connect(ui->mainViewButton, SIGNAL(clicked()), this, SLOT(CallViewDialog()));
     connect(ui->mainAboutButton, SIGNAL(clicked()), this, SLOT(openAboutDialog()));
     connect(ui->mainResetButton, SIGNAL(clicked()), this, SLOT(reset()));
+    connect(ui->mainExportButton, SIGNAL(clicked()), this, SLOT(exportDB()));
 
     QDBusConnection::sessionBus().registerService("com.nokia.dlh");
     QDBusConnection::sessionBus().registerObject("/com/nokia/dlh", this, QDBusConnection::ExportAllContents);
@@ -117,3 +118,33 @@ void Widget::reset() {
         query.exec(command);
     }
 }
+
+void Widget::exportDB() {
+    QString fileName = QFileDialog::getSaveFileName(this, tr("Select export file"),
+                                                          QString("/home/user/MyDocs/.documents/dlh.csv"));
+    if(fileName.isEmpty()) return;
+    QFile file(fileName);
+    if(!file.open(QFile::WriteOnly | QFile::Truncate)) {
+        QMessageBox::critical(this, tr("Unable to open the export file"),
+                                    tr("Do you have the permission to write this file?"));
+        return;
+    }
+    QTextStream csv(&file);
+    csv << tr("Start time,Finish time,Weight before,Weight after,Weight difference,ml before,ml after,ml difference,Note") << endl;
+    QSqlTableModel model;
+    model.setTable("dlh");
+    model.setEditStrategy(QSqlTableModel::OnManualSubmit);
+    model.select();
+    for(int row = 0; row < model.rowCount(); row++) {
+        csv << model.record(row).value("start").toString() << QString(",");
+        csv << model.record(row).value("end").toString() << QString(",");
+        csv << model.record(row).value("wb").toString() << QString(",");
+        csv << model.record(row).value("wa").toString() << QString(",");
+        csv << model.record(row).value("dw").toString() << QString(",");
+        csv << model.record(row).value("mlb").toString() << QString(",");
+        csv << model.record(row).value("mla").toString() << QString(",");
+        csv << model.record(row).value("dml").toString() << QString(",");
+        csv << QString("\"") << model.record(row).value("note").toString() << QString("\"") << endl;
+    }
+    file.close();
+}
