@@ -17,6 +17,7 @@
     along with dlh.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include <QHeaderView>
 #include "tableview.h"
 
 TableView::TableView(QWidget *parent) : QTableView(parent) {
@@ -24,6 +25,9 @@ TableView::TableView(QWidget *parent) : QTableView(parent) {
 
 void TableView::init(QSqlTableModel *model) {
     setModel(model);
-    resizeColumnsToContents();
     setEditTriggers(NoEditTriggers);
+    setSelectionMode(QAbstractItemView::NoSelection);
+    resizeColumnsToContents();
+    setColumnWidth(8, 500);
+    scrollToBottom();
 }
